@@ -38,21 +38,15 @@ class api:
         response = Response()
         response.status_code = 200
         response.text = "Blank"
-        with open("access-log.txt", "a") as f:
-            f.write("\n")
-            f.write(('127.0.0.1 - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ '] GET / HTTP/1.1" 200'))
-            for key in request.keys():
-                f.write(key + ":" + request[key])
-            f.write("\n")
         
         handler = self.find_handler(request)
 
         if handler is not None:
             handler(response)
         else:
-            print(self.getFileType(request.path)[1])
             try:
                 try:
+                    print(self.getFileType(request.path)[1])
                     return Response(body=(open(os.path.join(self.staticDir,"static"+request.path), "rb")).read(), content_type=self.getFileType(request.path)[1])
                 except Exception as e:
                     print(e)
@@ -61,6 +55,15 @@ class api:
                 print(e)
                 response.text = "Well My Work Was Not Clean Enough, but...<br><b>Thats A Server Problem</b>"
                 response.status_code = 500
+
+        with open("access-log.txt", "a") as f:
+            f.write("\n")
+            f.write((request.remote_addr + ' - - ['+(datetime.date.today().__str__())+' '+(datetime.datetime.now().strftime("%H:%M:%S"))+ ']' + request.method))
+            f.write("\n")
+            f.write("Request" + ":" + request.path)
+            f.write("\n")
+            f.write("Response Code" + ":" + response.status_code.__str__())
+            f.write("\n")
         return response
 
     def catchURL(self, path):
